"""Auto-generated file, do not edit by hand. SO metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_SO = PhoneMetadata(id='SO', country_code=252, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='[346-9]\\d{8}|[12679]\\d{7}|(?:[1-4]\\d|59)\\d{5}|[1348]\\d{5}', possible_length=(6, 7, 8, 9)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:1\\d|2[0-79]|3[0-46-8]|4[0-7]|59)\\d{5}|(?:[134]\\d|8[125])\\d{4}', example_number='4012345', possible_length=(6, 7)),
    mobile=PhoneNumberDesc(national_number_pattern='28\\d{5}|(?:6[1-9]|79)\\d{6,7}|(?:15|24|(?:3[59]|4[89]|8[08])\\d|60|7[1-8]|9(?:0[67]|[2-9]))\\d{6}', example_number='71123456', possible_length=(7, 8, 9)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['8[125]']),
        NumberFormat(pattern='(\\d{6})', format='\\1', leading_digits_pattern=['[134]']),
        NumberFormat(pattern='(\\d)(\\d{6})', format='\\1 \\2', leading_digits_pattern=['1|2[0-79]|3[0-46-8]|4[0-7]|59']),
        NumberFormat(pattern='(\\d)(\\d{7})', format='\\1 \\2', leading_digits_pattern=['24|[67]']),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['[348]|64|79[0-8]|90']),
        NumberFormat(pattern='(\\d{2})(\\d{5,7})', format='\\1 \\2', leading_digits_pattern=['1|28|6[1-35-9]|799|9[2-9]'])])



"""Auto-generated file, do not edit by hand. UG metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_UG = PhoneMetadata(id='UG', country_code=256, international_prefix='00[057]',
    general_desc=PhoneNumberDesc(national_number_pattern='800\\d{6}|(?:[29]0|[347]\\d)\\d{7}', possible_length=(9,), possible_length_local_only=(5, 6, 7)),
    fixed_line=PhoneNumberDesc(national_number_pattern='20(?:(?:240|30[0-4])\\d|6(?:00[0-2]|30[0-4]))\\d{3}|(?:20(?:[0147]\\d|[26][5-9]|3[2367]|5[0-4]|8[0-2])|[34]\\d{3})\\d{5}', example_number='312345678', possible_length=(9,), possible_length_local_only=(5, 6, 7)),
    mobile=PhoneNumberDesc(national_number_pattern='7260\\d{5}|7(?:[0157-9]\\d|2[03]|30|4[0-4])\\d{6}', example_number='712345678', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800[1-3]\\d{5}', example_number='800123456', possible_length=(9,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='90[1-3]\\d{6}', example_number='901123456', possible_length=(9,)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{4})(\\d{5})', format='\\1 \\2', leading_digits_pattern=['202', '2024'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{6})', format='\\1 \\2', leading_digits_pattern=['[27-9]|4(?:6[45]|[7-9])'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{7})', format='\\1 \\2', leading_digits_pattern=['[34]'], national_prefix_formatting_rule='0\\1')])



"""Auto-generated file, do not edit by hand. KI metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_KI = PhoneMetadata(id='KI', country_code=686, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[37]\\d|6[0-79])\\d{6}|(?:[2-48]\\d|50)\\d{3}', possible_length=(5, 8)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:[24]\\d|3[1-9]|50|65(?:02[12]|12[56]|22[89]|[3-5]00)|7(?:27\\d\\d|3100|5(?:02[12]|12[56]|22[89]|[34](?:00|81)|500))|8[0-5])\\d{3}', example_number='31234', possible_length=(5, 8)),
    mobile=PhoneNumberDesc(national_number_pattern='73140\\d{3}|(?:630[01]|730[0-5])\\d{4}|[67]200[01]\\d{3}', example_number='72001234', possible_length=(8,)),
    voip=PhoneNumberDesc(national_number_pattern='30(?:0[01]\\d\\d|12(?:11|20))\\d\\d', example_number='30010000', possible_length=(8,)),
    national_prefix='0',
    national_prefix_for_parsing='0')



"""Auto-generated file, do not edit by hand. CD metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_CD = PhoneMetadata(id='CD', country_code=243, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='[189]\\d{8}|[1-68]\\d{6}', possible_length=(7, 9)),
    fixed_line=PhoneNumberDesc(national_number_pattern='12\\d{7}|[1-6]\\d{6}', example_number='1234567', possible_length=(7, 9)),
    mobile=PhoneNumberDesc(national_number_pattern='88\\d{5}|(?:8[0-2459]|9[017-9])\\d{7}', example_number='991234567', possible_length=(7, 9)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{2})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['88'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{5})', format='\\1 \\2', leading_digits_pattern=['[1-6]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['1'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['[89]'], national_prefix_formatting_rule='0\\1')])



"""Auto-generated file, do not edit by hand. NZ metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_NZ = PhoneMetadata(id='NZ', country_code=64, international_prefix='0(?:0|161)',
    general_desc=PhoneNumberDesc(national_number_pattern='[28]\\d{7,9}|[346]\\d{7}|(?:508|[79]\\d)\\d{6,7}', possible_length=(8, 9, 10), possible_length_local_only=(7,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='24099\\d{3}|(?:3[2-79]|[49][2-9]|6[235-9]|7[2-57-9])\\d{6}', example_number='32345678', possible_length=(8,), possible_length_local_only=(7,)),
    mobile=PhoneNumberDesc(national_number_pattern='2[0-28]\\d{8}|2[0-27-9]\\d{7}|21\\d{6}', example_number='211234567', possible_length=(8, 9, 10)),
    toll_free=PhoneNumberDesc(national_number_pattern='508\\d{6,7}|80\\d{6,8}', example_number='800123456', possible_length=(8, 9, 10)),
    premium_rate=PhoneNumberDesc(national_number_pattern='90\\d{6,7}', example_number='900123456', possible_length=(8, 9)),
    personal_number=PhoneNumberDesc(national_number_pattern='70\\d{7}', example_number='701234567', possible_length=(9,)),
    pager=PhoneNumberDesc(national_number_pattern='[28]6\\d{6,7}', example_number='26123456', possible_length=(8, 9)),
    preferred_international_prefix='00',
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{2})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['[89]0'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d)(\\d{3})(\\d{4})', format='\\1-\\2 \\3', leading_digits_pattern=['24|[346]|7[2-57-9]|9[2-9]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3,4})', format='\\1 \\2 \\3', leading_digits_pattern=['2(?:10|74)|[59]|80'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3,4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['2[028]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{3,5})', format='\\1 \\2 \\3', leading_digits_pattern=['2(?:[169]|7[0-35-9])|7|86'], national_prefix_formatting_rule='0\\1')],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. GE metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_GE = PhoneMetadata(id='GE', country_code=995, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[3-57]\\d\\d|800)\\d{6}', possible_length=(9,), possible_length_local_only=(6, 7)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:3(?:[256]\\d|4[124-9]|7[0-4])|4(?:1\\d|2[2-7]|3[1-79]|4[2-8]|7[239]|9[1-7]))\\d{6}', example_number='322123456', possible_length=(9,), possible_length_local_only=(6, 7)),
    mobile=PhoneNumberDesc(national_number_pattern='(?:5(?:[14]4|5[0157-9]|68|7[0147-9]|9[1-35-9])|790)\\d{6}', example_number='555123456', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800\\d{6}', example_number='800123456', possible_length=(9,)),
    voip=PhoneNumberDesc(national_number_pattern='706\\d{6}', example_number='706123456', possible_length=(9,)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='706\\d{6}', possible_length=(9,)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['70'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['32'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{2})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['[57]']),
        NumberFormat(pattern='(\\d{3})(\\d{2})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['[348]'], national_prefix_formatting_rule='0\\1')],
    mobile_number_portable_region=True)



"""PhoneMetadata object definitions"""

# Based on original Java code and protocol buffer:
#     resources/phonemetadata.proto
#     java/src/com/google/i18n/phonenumbers/Phonemetadata.java
#   Copyright (C) 2010-2011 The Libphonenumber Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from .util import UnicodeMixin, ImmutableMixin, mutating_method
from .util import u, unicod, rpr, force_unicode

REGION_CODE_FOR_NON_GEO_ENTITY = u("001")


class NumberFormat(UnicodeMixin, ImmutableMixin):
    """Representation of way that a phone number can be formatted for output"""
    @mutating_method
    def __init__(self,
                 pattern=None,
                 format=None,
                 leading_digits_pattern=None,
                 national_prefix_formatting_rule=None,
                 national_prefix_optional_when_formatting=None,
                 domestic_carrier_code_formatting_rule=None):
        # pattern is a regex that is used to match the national (significant)
        # number. For example, the pattern "(20)(\d{4})(\d{4})" will match
        # number "2070313000", which is the national (significant) number for
        # Google London. Note the presence of the parentheses, which are
        # capturing groups what specifies the grouping of numbers.
        self.pattern = force_unicode(pattern)  # Unicode string holding regexp

        # format specifies how the national (significant) number matched by
        # pattern should be formatted. Using the same example as above, format
        # could contain "$1 $2 $3", meaning that the number should be
        # formatted as "20 7031 3000". Each $x is replaced by the numbers
        # captured by group x in the regex specified by pattern.
        self.format = force_unicode(format)  # None or Unicode string

        # This field is a regex that is used to match a certain number of
        # digits at the beginning of the national (significant) number. When
        # the match is successful, the accompanying pattern and format should
        # be used to format this number. For example, if
        # leading_digits="[1-3]|44", then all the national numbers starting
        # with 1, 2, 3 or 44 should be formatted using the accompanying
        # pattern and format.
        #
        # The first leading_digits_pattern matches up to the first three digits
        # of the national (significant) number; the next one matches the first
        # four digits, then the first five and so on, until the
        # leading_digits_pattern can uniquely identify one pattern and format
        # to be used to format the number.
        #
        # In the case when only one formatting pattern exists, no
        # leading_digits_pattern is needed.
        self.leading_digits_pattern = []  # list of Unicode strings holding regexps
        if leading_digits_pattern is not None:
            self.leading_digits_pattern = [force_unicode(p) for p in leading_digits_pattern]

        # This field specifies how the national prefix ($NP) together with the
        # first group ($FG) in the national significant number should be
        # formatted in the NATIONAL format when a national prefix exists for a
        # certain country. For example, when this field contains "($NP$FG)", a
        # number from Beijing, China (whose $NP = 0), which would by default
        # be formatted without national prefix as 10 1234 5678 in NATIONAL
        # format, will instead be formatted as (010) 1234 5678; to format it
        # as (0)10 1234 5678, the field would contain "($NP)$FG". Note $FG
        # should always be present in this field, but $NP can be omitted. For
        # example, having "$FG" could indicate the number should be formatted
        # in NATIONAL format without the national prefix. This is commonly
        # used to override the rule specified for the territory in the XML
        # file.
        #
        # When this field is missing, a number will be formatted without
        # national prefix in NATIONAL format. This field does not affect how a
        # number is formatted in other formats, such as INTERNATIONAL.
        self.national_prefix_formatting_rule = force_unicode(national_prefix_formatting_rule)  # None or Unicode string

        # This field specifies whether the $NP can be omitted when formatting
        # a number in national format, even though it usually wouldn't be. For
        # example, a UK number would be formatted by our library as 020 XXXX
        # XXXX. If we have commonly seen this number written by people without
        # the leading 0, for example as (20) XXXX XXXX, this field would be
        # set to true. This will be inherited from the value set for the
        # territory in the XML file, unless a national_prefix_formatting_rule
        # is defined specifically for this NumberFormat.
        if national_prefix_optional_when_formatting is not None:
            self.national_prefix_optional_when_formatting = bool(national_prefix_optional_when_formatting)
        else:
            self.national_prefix_optional_when_formatting = None

        # This field specifies how any carrier code ($CC) together with the
        # first group ($FG) in the national significant number should be
        # formatted when format_with_carrier_code is called, if carrier codes
        # are used for a certain country.
        self.domestic_carrier_code_formatting_rule = force_unicode(domestic_carrier_code_formatting_rule)  # None or Unicode string

    def merge_from(self, other):
        """Merge information from another NumberFormat object into this one."""
        if other.pattern is not None:
            self.pattern = other.pattern
        if other.format is not None:
            self.format = other.format
        self.leading_digits_pattern.extend(other.leading_digits_pattern)
        if other.national_prefix_formatting_rule is not None:
            self.national_prefix_formatting_rule = other.national_prefix_formatting_rule
        if other.national_prefix_optional_when_formatting is not None:
            self.national_prefix_optional_when_formatting = other.national_prefix_optional_when_formatting
        if other.domestic_carrier_code_formatting_rule is not None:
            self.domestic_carrier_code_formatting_rule = other.domestic_carrier_code_formatting_rule

    def __eq__(self, other):
        if not isinstance(other, NumberFormat):
            return False
        return (repr(self) == repr(other))

    def __ne__(self, other):
        return not self.__eq__(other)

    def __repr__(self):
        return str(self)

    def __unicode__(self):
        # Generate a string that is valid Python input for the constructor.
        # Note that we use rpr (variant of repr), which generates its own quotes.
        result = unicod("NumberFormat(pattern=%s, format=%s") % (rpr(self.pattern), rpr(self.format))
        if self.leading_digits_pattern:
            result += (unicod(", leading_digits_pattern=[%s]") %
                       unicod(", ").join([rpr(ld) for ld in self.leading_digits_pattern]))
        if self.national_prefix_formatting_rule is not None:
            result += unicod(", national_prefix_formatting_rule=%s") % rpr(self.national_prefix_formatting_rule)
        if self.national_prefix_optional_when_formatting is not None:
            result += unicod(", national_prefix_optional_when_formatting=%s") % str(self.national_prefix_optional_when_formatting)
        if self.domestic_carrier_code_formatting_rule is not None:
            result += unicod(", domestic_carrier_code_formatting_rule=%s") % rpr(self.domestic_carrier_code_formatting_rule)
        result += unicod(")")
        return result


class PhoneNumberDesc(UnicodeMixin, ImmutableMixin):
    """Class representing the description of a set of phone numbers."""
    @mutating_method
    def __init__(self,
                 national_number_pattern=None,
                 example_number=None,
                 possible_length=None,
                 possible_length_local_only=None):
        # The national_number_pattern is the pattern that a valid national
        # significant number would match. This specifies information such as
        # its total length and leading digits.
        self.national_number_pattern = force_unicode(national_number_pattern)  # None or Unicode string holding regexp

        # An example national significant number for the specific type. It
        # should not contain any formatting information.
        self.example_number = force_unicode(example_number)  # None or Unicode string

        # These represent the lengths a phone number from this region can be. They
        # will be sorted from smallest to biggest. Note that these lengths are for
        # the full number, without country calling code or national prefix. For
        # example, for the Swiss number +41789270000, in local format 0789270000,
        # this would be 9.
        # This could be used to highlight tokens in a text that may be a phone
        # number, or to quickly prune numbers that could not possibly be a phone
        # number for this locale.
        if possible_length is None:
            possible_length = ()
        self.possible_length = possible_length  # sequence of int

        # These represent the lengths that only local phone numbers (without an area
        # code) from this region can be. They will be sorted from smallest to
        # biggest. For example, since the American number 456-1234 may be locally
        # diallable, although not diallable from outside the area, 7 could be a
        # possible value.
        # This could be used to highlight tokens in a text that may be a phone
        # number.
        # To our knowledge, area codes are usually only relevant for some fixed-line
        # and mobile numbers, so this field should only be set for those types of
        # numbers (and the general description) - however there are exceptions for
        # NANPA countries.
        if possible_length_local_only is None:
            possible_length_local_only = ()
        self.possible_length_local_only = possible_length_local_only  # sequence of int

    def merge_from(self, other):
        """Merge information from another PhoneNumberDesc object into this one."""
        if other.national_number_pattern is not None:
            self.national_number_pattern = other.national_number_pattern
        if other.example_number is not None:
            self.example_number = other.example_number

    def __eq__(self, other):
        if not isinstance(other, PhoneNumberDesc):
            return False
        return (repr(self) == repr(other))

    def __ne__(self, other):
        return not self.__eq__(other)

    def __repr__(self):
        return str(self)

    def __unicode__(self):
        # Generate a string that is valid Python input for constructor
        result = unicod("PhoneNumberDesc(")
        sep = unicod("")
        if self.national_number_pattern is not None:
            result += unicod("%snational_number_pattern=%s") % (sep, rpr(self.national_number_pattern))
            sep = unicod(", ")
        if self.example_number is not None:
            result += unicod("%sexample_number=%s") % (sep, rpr(self.example_number))
            sep = unicod(", ")
        if self.possible_length:
            result += unicod("%spossible_length=%s") % (sep, tuple(self.possible_length))
            sep = unicod(", ")
        if self.possible_length_local_only:
            result += unicod("%spossible_length_local_only=%s") % (sep, tuple(self.possible_length_local_only))
            sep = unicod(", ")
        result += unicod(")")
        return result


def _same_pattern(left, right):
    if left is None and right is None:
        return True
    if left is None or right is None:
        return False
    return (left.national_number_pattern == right.national_number_pattern)


class PhoneMetadata(UnicodeMixin, ImmutableMixin):
    """Class representing metadata for international telephone numbers for a region.

    This class is hand created based on phonemetadata.proto. Please refer to that file
    for detailed descriptions of the meaning of each field.

    WARNING: This API isn't stable. It is considered libphonenumber-internal
    and can change at any time. We only declare it as public for easy
    inclusion in our build tools not in this package.  Clients should not
    refer to this file, we do not commit to support backwards-compatibility or
    to warn about breaking changes.

    """
    # If a region code is a key in this dict, metadata for that region is available.
    # The corresponding value of the map is either:
    #   - a function which loads the region's metadata
    #   - None, to indicate that the metadata is already loaded
    _region_available = {}  # ISO 3166-1 alpha 2 => function or None
    # Likewise for short number metadata.
    _short_region_available = {}  # ISO 3166-1 alpha 2 => function or None
    # Likewise for non-geo country calling codes.
    _country_code_available = {}  # country calling code (as int) => function or None

    _region_metadata = {}  # ISO 3166-1 alpha 2 => PhoneMetadata
    _short_region_metadata = {}  # ISO 3166-1 alpha 2 => PhoneMetadata
    # A mapping from a country calling code for a non-geographical entity to
    # the PhoneMetadata for that country calling code. Examples of the country
    # calling codes include 800 (International Toll Free Service) and 808
    # (International Shared Cost Service).
    _country_code_metadata = {}  # country calling code (as int) => PhoneMetadata

    @classmethod
    def metadata_for_region(kls, region_code, default=None):
        loader = kls._region_available.get(region_code, None)
        if loader is not None:
            # Region metadata is available but has not yet been loaded.  Do so now.
            loader(region_code)
            kls._region_available[region_code] = None
        return kls._region_metadata.get(region_code, default)

    @classmethod
    def short_metadata_for_region(kls, region_code, default=None):
        loader = kls._short_region_available.get(region_code, None)
        if loader is not None:
            # Region short number metadata is available but has not yet been loaded.  Do so now.
            loader(region_code)
            kls._short_region_available[region_code] = None
        return kls._short_region_metadata.get(region_code, default)

    @classmethod
    def metadata_for_nongeo_region(kls, country_code, default=None):
        loader = kls._country_code_available.get(country_code, None)
        if loader is not None:
            # Region metadata is available but has not yet been loaded.  Do so now.
            loader(country_code)
            kls._country_code_available[country_code] = None
        return kls._country_code_metadata.get(country_code, default)

    @classmethod
    def metadata_for_region_or_calling_code(kls, country_calling_code, region_code):
        if region_code == REGION_CODE_FOR_NON_GEO_ENTITY:
            return kls.metadata_for_nongeo_region(country_calling_code, None)
        else:
            return kls.metadata_for_region(region_code, None)

    @classmethod
    def register_region_loader(kls, region_code, loader):
        kls._region_available[region_code] = loader

    @classmethod
    def register_short_region_loader(kls, region_code, loader):
        kls._short_region_available[region_code] = loader

    @classmethod
    def register_nongeo_region_loader(kls, country_code, loader):
        kls._country_code_available[country_code] = loader

    @classmethod
    def load_all(kls):
        """Force immediate load of all metadata"""
        # Force expansion of contents to lists because we invalidate the iterator
        for region_code, loader in list(kls._region_available.items()):
            if loader is not None:  # pragma no cover
                loader(region_code)
                kls._region_available[region_code] = None
        for country_code, loader in list(kls._country_code_available.items()):
            if loader is not None:
                loader(country_code)
                kls._country_code_available[region_code] = None

    @mutating_method
    def __init__(self,
                 id,
                 general_desc=None,
                 fixed_line=None,
                 mobile=None,
                 toll_free=None,
                 premium_rate=None,
                 shared_cost=None,
                 personal_number=None,
                 voip=None,
                 pager=None,
                 uan=None,
                 emergency=None,
                 voicemail=None,
                 short_code=None,
                 standard_rate=None,
                 carrier_specific=None,
                 sms_services=None,
                 no_international_dialling=None,
                 country_code=None,
                 international_prefix=None,
                 preferred_international_prefix=None,
                 national_prefix=None,
                 preferred_extn_prefix=None,
                 national_prefix_for_parsing=None,
                 national_prefix_transform_rule=None,
                 number_format=None,
                 intl_number_format=None,
                 main_country_for_code=False,
                 leading_digits=None,
                 leading_zero_possible=False,
                 mobile_number_portable_region=False,
                 short_data=False,
                 register=True):
        # The general_desc contains information which is a superset of
        # descriptions for all types of phone numbers. If any element is
        # missing in the description of a specific type of number, the element
        # will inherit from its counterpart in the general_desc. For all types
        # that are generally relevant to normal phone numbers, if the whole
        # type is missing in the PhoneNumberMetadata XML file, it will not have
        # national number data, and the possible lengths will be [-1].
        self.general_desc = general_desc  # None or PhoneNumberDesc
        self.fixed_line = fixed_line  # None or PhoneNumberDesc
        self.mobile = mobile  # None or PhoneNumberDesc
        self.toll_free = toll_free  # None or PhoneNumberDesc
        self.premium_rate = premium_rate  # None or PhoneNumberDesc
        self.shared_cost = shared_cost  # None or PhoneNumberDesc
        self.personal_number = personal_number  # None or PhoneNumberDesc
        self.voip = voip  # None or PhoneNumberDesc
        self.pager = pager  # None or PhoneNumberDesc
        self.uan = uan  # None or PhoneNumberDesc
        self.emergency = emergency  # None or PhoneNumberDesc
        self.voicemail = voicemail  # None or PhoneNumberDesc
        self.short_code = short_code  # None or PhoneNumberDesc
        self.standard_rate = standard_rate  # None or PhoneNumberDesc
        self.carrier_specific = carrier_specific  # None or PhoneNumberDesc
        self.sms_services = sms_services  # None or PhoneNumberDesc

        # The rules here distinguish the numbers that are only able to be
        # dialled nationally.
        self.no_international_dialling = no_international_dialling  # None or PhoneNumberDesc

        # The ISO 3166-1 alpha-2 representation of a country/region, with the
        # exception of "country calling codes" used for non-geographical
        # entities, such as Universal International Toll Free Number
        # (+800). These are all given the ID "001", since this is the numeric
        # region code for the world according to UN M.49:
        # http://en.wikipedia.org/wiki/UN_M.49
        self.id = force_unicode(id)  # None or Unicode string

        # The country calling code that one would dial from overseas when
        # trying to dial a phone number in this country. For example, this
        # would be "64" for New Zealand.
        self.country_code = country_code  # None or int

        # The international_prefix of country A is the number that needs to be
        # dialled from country A to another country (country B). This is
        # followed by the country code for country B. Note that some countries
        # may have more than one international prefix, and for those cases, a
        # regular expression matching the international prefixes will be
        # stored in this field.
        self.international_prefix = force_unicode(international_prefix)  # None or Unicode string

        # If more than one international prefix is present, a preferred prefix
        # can be specified here for out-of-country formatting purposes. If
        # this field is not present, and multiple international prefixes are
        # present, then "+" will be used instead.
        self.preferred_international_prefix = force_unicode(preferred_international_prefix)  # None or Unicode string

        # The national prefix of country A is the number that needs to be
        # dialled before the national significant number when dialling
        # internally. This would not be dialled when dialling
        # internationally. For example, in New Zealand, the number that would
        # be locally dialled as 09 345 3456 would be dialled from overseas as
        # +64 9 345 3456. In this case, 0 is the national prefix.
        self.national_prefix = force_unicode(national_prefix)  # None or Unicode string

        # The preferred prefix when specifying an extension in this
        # country. This is used for formatting only, and if this is not
        # specified, a suitable default should be used instead. For example,
        # if you wanted extensions to be formatted in the following way: 1
        # (365) 345 445 ext. 2345 " ext. "  should be the preferred extension
        # prefix.
        self.preferred_extn_prefix = force_unicode(preferred_extn_prefix)  # None or Unicode string

        # This field is used for cases where the national prefix of a country
        # contains a carrier selection code, and is written in the form of a
        # regular expression. For example, to dial the number 2222-2222 in
        # Fortaleza, Brazil (area code 85) using the long distance carrier Oi
        # (selection code 31), one would dial 0 31 85 2222 2222. Assuming the
        # only other possible carrier selection code is 32, the field will
        # contain "03[12]".
        #
        # When it is missing, this field inherits the value of national_prefix,
        # if that is present.
        self.national_prefix_for_parsing = force_unicode(national_prefix_for_parsing)  # None or Unicode string holding regexp

        # This field is only populated and used under very rare situations.
        # For example, mobile numbers in Argentina are written in two
        # completely different ways when dialed in-country and out-of-country
        # (e.g. 0343 15 555 1212 is exactly the same number as +54 9 343 555
        # 1212).  This field is used together with national_prefix_for_parsing
        # to transform the number into a particular representation for storing
        # in the PhoneNumber class in those rare cases.
        self.national_prefix_transform_rule = force_unicode(national_prefix_transform_rule)  # None or Unicode string

        # Specifies whether the mobile and fixed-line patterns are the same or
        # not.  This is used to speed up determining phone number type in
        # countries where these two types of phone numbers can never be
        # distinguished.
        self.same_mobile_and_fixed_line_pattern = _same_pattern(self.mobile, self.fixed_line)

        # Note that the number format here is used for formatting only, not
        # parsing.  Hence all the varied ways a user *may* write a number need
        # not be recorded - just the ideal way we would like to format it for
        # them. When this element is absent, the national significant number
        # will be formatted as a whole without any formatting applied.
        self.number_format = []  # List of NumberFormat objects
        if number_format is not None:
            self.number_format = number_format

        # This field is populated only when the national significant number is
        # formatted differently when it forms part of the INTERNATIONAL format
        # and NATIONAL format. A case in point is mobile numbers in Argentina:
        # The number, which would be written in INTERNATIONAL format as
        # +54 9 343 555 1212, will be written as 0343 15 555 1212 for NATIONAL
        # format. In this case, the prefix 9 is inserted when dialling from
        # overseas, but otherwise the prefix 0 and the carrier selection code
        # 15 (inserted after the area code of 343) is used.
        # Note: this field is populated by setting a value for <intlFormat>
        # inside the <numberFormat> tag in the XML file. If <intlFormat> is
        # not set then it defaults to the same value as the <format> tag.
        #
        # Examples:
        #   To set the <intlFormat> to a different value than the <format>:
        #     <numberFormat pattern=....>
        #       <format>$1 $2 $3</format>
        #       <intlFormat>$1-$2-$3</intlFormat>
        #     </numberFormat>
        #
        #   To have a format only used for national formatting, set <intlFormat> to
        #   "NA":
        #     <numberFormat pattern=....>
        #       <format>$1 $2 $3</format>
        #       <intlFormat>NA</intlFormat>
        #     </numberFormat>
        self.intl_number_format = []  # List of NumberFormat objects
        if intl_number_format is not None:
            self.intl_number_format = intl_number_format

        # This field is set when this country is considered to be the main
        # country for a calling code. It may not be set by more than one
        # country with the same calling code, and it should not be set by
        # countries with a unique calling code. This can be used to indicate
        # that "GB" is the main country for the calling code "44" for example,
        # rather than Jersey or the Isle of Man.
        self.main_country_for_code = bool(main_country_for_code)

        # This field is populated only for countries or regions that share a
        # country calling code. If a number matches this pattern, it could
        # belong to this region. This is not intended as a replacement for
        # is_valid_for_region, and does not mean the number must come from this
        # region (for example, 800 numbers are valid for all NANPA countries.)
        # This field should be a regular expression of the expected prefix
        # match.
        self.leading_digits = force_unicode(leading_digits)  # None or Unicode string holding regexp

        # Deprecated: do not use. Will be deleted when there are no references
        # to this later.
        self.leading_zero_possible = bool(leading_zero_possible)

        # This field is set when this country has implemented mobile number
        # portability. This means that transferring mobile numbers between
        # carriers is allowed. A consequence of this is that phone prefix to
        # carrier mapping is less reliable.
        self.mobile_number_portable_region = mobile_number_portable_region  # bool

        # Record whether this metadata is for short numbers or normal numbers.
        self.short_data = short_data  # bool

        if register:
            # Register this instance with the relevant class-wide map
            if self.id == REGION_CODE_FOR_NON_GEO_ENTITY:
                kls_map = PhoneMetadata._country_code_metadata
                id = self.country_code
            elif self.short_data:
                kls_map = PhoneMetadata._short_region_metadata
                id = self.id
            else:
                kls_map = PhoneMetadata._region_metadata
                id = self.id
            if id in kls_map:
                other = kls_map[id]
                if self != other:
                    raise Exception("Duplicate PhoneMetadata for %s (from %s:%s)" % (id, self.id, self.country_code))
            else:
                kls_map[id] = self

    def __eq__(self, other):
        if not isinstance(other, PhoneMetadata):
            return False
        return (repr(self) == repr(other))

    def __ne__(self, other):
        return not self.__eq__(other)

    def __repr__(self):
        return str(self)

    def __unicode__(self):
        # Generate a string that is valid Python input for the constructor
        result = (unicod("PhoneMetadata(id='%s', country_code=%r, international_prefix=%s") %
                  (self.id, self.country_code, rpr(self.international_prefix)))
        result += unicod(",\n    general_desc=%s") % self.general_desc
        if self.fixed_line is not None:
            result += unicod(",\n    fixed_line=%s") % self.fixed_line
        if self.mobile is not None:
            result += unicod(",\n    mobile=%s") % self.mobile
        if self.toll_free is not None:
            result += unicod(",\n    toll_free=%s") % self.toll_free
        if self.premium_rate is not None:
            result += unicod(",\n    premium_rate=%s") % self.premium_rate
        if self.shared_cost is not None:
            result += unicod(",\n    shared_cost=%s") % self.shared_cost
        if self.personal_number is not None:
            result += unicod(",\n    personal_number=%s") % self.personal_number
        if self.voip is not None:
            result += unicod(",\n    voip=%s") % self.voip
        if self.pager is not None:
            result += unicod(",\n    pager=%s") % self.pager
        if self.uan is not None:
            result += unicod(",\n    uan=%s") % self.uan
        if self.emergency is not None:
            result += unicod(",\n    emergency=%s") % self.emergency
        if self.voicemail is not None:
            result += unicod(",\n    voicemail=%s") % self.voicemail
        if self.short_code is not None:
            result += unicod(",\n    short_code=%s") % self.short_code
        if self.standard_rate is not None:
            result += unicod(",\n    standard_rate=%s") % self.standard_rate
        if self.carrier_specific is not None:
            result += unicod(",\n    carrier_specific=%s") % self.carrier_specific
        if self.sms_services is not None:
            result += unicod(",\n    sms_services=%s") % self.sms_services
        if self.no_international_dialling is not None:
            result += unicod(",\n    no_international_dialling=%s") % self.no_international_dialling

        if self.preferred_international_prefix is not None:
            result += unicod(",\n    preferred_international_prefix=%s") % rpr(self.preferred_international_prefix)
        if self.national_prefix is not None:
            result += unicod(",\n    national_prefix=%s") % rpr(self.national_prefix)
        if self.preferred_extn_prefix is not None:
            result += unicod(",\n    preferred_extn_prefix=%s") % rpr(self.preferred_extn_prefix)
        if self.national_prefix_for_parsing is not None:
            result += unicod(",\n    national_prefix_for_parsing=%s") % rpr(self.national_prefix_for_parsing)
        if self.national_prefix_transform_rule is not None:
            # Note that we use rpr() on self.national_prefix_transform_rule, which generates its own quotes
            result += unicod(",\n    national_prefix_transform_rule=%s") % rpr(self.national_prefix_transform_rule)
        if self.number_format:
            result += unicod(",\n    number_format=[%s]") % unicod(',\n        ').join(map(u, self.number_format))
        if self.intl_number_format:
            result += unicod(",\n    intl_number_format=[%s]") % unicod(',\n        ').join(map(u, self.intl_number_format))
        if self.main_country_for_code:
            result += unicod(",\n    main_country_for_code=True")
        if self.leading_digits is not None:
            result += unicod(",\n    leading_digits='%s'") % self.leading_digits
        if self.leading_zero_possible:
            result += unicod(",\n    leading_zero_possible=True")
        if self.mobile_number_portable_region:
            result += unicod(",\n    mobile_number_portable_region=True")
        if self.short_data:
            result += unicod(",\n    short_data=True")
        result += unicod(")")
        return result



"""Auto-generated file, do not edit by hand. IE metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_IE = PhoneMetadata(id='IE', country_code=353, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:1\\d|[2569])\\d{6,8}|4\\d{6,9}|7\\d{8}|8\\d{8,9}', possible_length=(7, 8, 9, 10), possible_length_local_only=(5, 6)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:1\\d|21)\\d{6,7}|(?:2[24-9]|4(?:0[24]|5\\d|7)|5(?:0[45]|1\\d|8)|6(?:1\\d|[237-9])|9(?:1\\d|[35-9]))\\d{5}|(?:23|4(?:[1-469]|8[0-46-9])|5[23679]|6[4-6]|7[14]|9[04])\\d{7}', example_number='2212345', possible_length=(7, 8, 9, 10), possible_length_local_only=(5, 6)),
    mobile=PhoneNumberDesc(national_number_pattern='8(?:22|[35-9]\\d)\\d{6}', example_number='850123456', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='1800\\d{6}', example_number='1800123456', possible_length=(10,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='15(?:1[2-8]|[2-8]0|9[089])\\d{6}', example_number='1520123456', possible_length=(10,)),
    shared_cost=PhoneNumberDesc(national_number_pattern='18[59]0\\d{6}', example_number='1850123456', possible_length=(10,)),
    personal_number=PhoneNumberDesc(national_number_pattern='700\\d{6}', example_number='700123456', possible_length=(9,)),
    voip=PhoneNumberDesc(national_number_pattern='76\\d{7}', example_number='761234567', possible_length=(9,)),
    uan=PhoneNumberDesc(national_number_pattern='818\\d{6}', example_number='818123456', possible_length=(9,)),
    voicemail=PhoneNumberDesc(national_number_pattern='8[35-9]5\\d{7}', example_number='8551234567', possible_length=(10,)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='18[59]0\\d{6}', possible_length=(10,)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{5})', format='\\1 \\2', leading_digits_pattern=['2[24-9]|47|58|6[237-9]|9[35-9]'], national_prefix_formatting_rule='(0\\1)'),
        NumberFormat(pattern='(\\d{3})(\\d{5})', format='\\1 \\2', leading_digits_pattern=['[45]0'], national_prefix_formatting_rule='(0\\1)'),
        NumberFormat(pattern='(\\d)(\\d{3,4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['1'], national_prefix_formatting_rule='(0\\1)'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{3,4})', format='\\1 \\2 \\3', leading_digits_pattern=['[2569]|4[1-69]|7[14]'], national_prefix_formatting_rule='(0\\1)'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['70'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['81'], national_prefix_formatting_rule='(0\\1)'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[78]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{4})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['1']),
        NumberFormat(pattern='(\\d{2})(\\d)(\\d{3})(\\d{4})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['8'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['4'], national_prefix_formatting_rule='(0\\1)')],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. PF metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_PF = PhoneMetadata(id='PF', country_code=689, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='[48]\\d{7}|4\\d{5}', possible_length=(6, 8)),
    fixed_line=PhoneNumberDesc(national_number_pattern='4(?:[09][4-689]\\d|4)\\d{4}', example_number='40412345', possible_length=(6, 8)),
    mobile=PhoneNumberDesc(national_number_pattern='8[7-9]\\d{6}', example_number='87123456', possible_length=(8,)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='44\\d{4}', possible_length=(6,)),
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{2})(\\d{2})', format='\\1 \\2 \\3', leading_digits_pattern=['44']),
        NumberFormat(pattern='(\\d{2})(\\d{2})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['[48]'])])



"""Auto-generated file, do not edit by hand. 255 metadata"""
from ..phonemetadata import NumberFormat

PHONE_ALT_FORMAT_255 = [NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[67]']), NumberFormat(pattern='(\\d{2})(\\d{4})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['[67]'])]



"""Auto-generated file, do not edit by hand. VU metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_VU = PhoneMetadata(id='VU', country_code=678, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[23]\\d|[48]8)\\d{3}|(?:[57]\\d|90)\\d{5}', possible_length=(5, 7)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:38[0-8]|48[4-9])\\d\\d|(?:2[02-9]|3[4-7]|88)\\d{3}', example_number='22123', possible_length=(5,)),
    mobile=PhoneNumberDesc(national_number_pattern='57[2-5]\\d{4}|(?:5[0-689]|7[013-7])\\d{5}', example_number='5912345', possible_length=(7,)),
    voip=PhoneNumberDesc(national_number_pattern='90[1-9]\\d{4}', example_number='9010123', possible_length=(7,)),
    uan=PhoneNumberDesc(national_number_pattern='(?:3[03]|900\\d)\\d{3}', example_number='30123', possible_length=(5, 7)),
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['[579]'])])



"""Auto-generated file, do not edit by hand. ML metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_ML = PhoneMetadata(id='ML', country_code=223, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[246-9]\\d|50)\\d{6}', possible_length=(8,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='2(?:07[0-8]|12[67])\\d{4}|(?:2(?:02|1[4-689])|4(?:0[0-4]|4[1-39]))\\d{5}', example_number='20212345', possible_length=(8,)),
    mobile=PhoneNumberDesc(national_number_pattern='2(?:079|17\\d)\\d{4}|(?:50|[679]\\d|8[239])\\d{6}', example_number='65012345', possible_length=(8,)),
    toll_free=PhoneNumberDesc(national_number_pattern='80\\d{6}', example_number='80012345', possible_length=(8,)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='80\\d{6}', possible_length=(8,)),
    number_format=[NumberFormat(pattern='(\\d{4})', format='\\1', leading_digits_pattern=['67[057-9]|74[045]', '67(?:0[09]|[59]9|77|8[89])|74(?:0[02]|44|55)']),
        NumberFormat(pattern='(\\d{2})(\\d{2})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['[24-9]'])],
    intl_number_format=[NumberFormat(pattern='(\\d{2})(\\d{2})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['[24-9]'])])



"""Auto-generated file, do not edit by hand. NP metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_NP = PhoneMetadata(id='NP', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='1\\d\\d', possible_length=(3,)),
    toll_free=PhoneNumberDesc(national_number_pattern='1(?:0[0-3]|12)', example_number='100', possible_length=(3,)),
    emergency=PhoneNumberDesc(national_number_pattern='1(?:0[0-3]|12)', example_number='100', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='1(?:0[0-3]|12)', example_number='100', possible_length=(3,)),
    short_data=True)



"""Auto-generated file, do not edit by hand. KW metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_KW = PhoneMetadata(id='KW', country_code=965, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:18|[2569]\\d\\d)\\d{5}', possible_length=(7, 8)),
    fixed_line=PhoneNumberDesc(national_number_pattern='2(?:[23]\\d\\d|4(?:[1-35-9]\\d|44)|5(?:0[034]|[2-46]\\d|5[1-3]|7[1-7]))\\d{4}', example_number='22345678', possible_length=(8,)),
    mobile=PhoneNumberDesc(national_number_pattern='(?:52(?:22|5[25])|6(?:222|70[013-9]|93[039])|9(?:11[01]|702))\\d{4}|(?:5(?:[05]\\d|1[0-7]|6[56])|6(?:0[034679]|5[015-9]|6\\d|7[67]|9[069])|9(?:0[09]|22|4[01479]|55|6[0679]|7[1-9]|8[057-9]|9\\d))\\d{5}', example_number='50012345', possible_length=(8,)),
    toll_free=PhoneNumberDesc(national_number_pattern='18\\d{5}', example_number='1801234', possible_length=(7,)),
    number_format=[NumberFormat(pattern='(\\d{4})(\\d{3,4})', format='\\1 \\2', leading_digits_pattern=['[169]|2(?:[235]|4[1-35-9])|52']),
        NumberFormat(pattern='(\\d{3})(\\d{5})', format='\\1 \\2', leading_digits_pattern=['[25]'])],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. 972 metadata"""
from ..phonemetadata import NumberFormat

PHONE_ALT_FORMAT_972 = [NumberFormat(pattern='(\\d)(\\d{3})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['[2-489]'])]



"""Auto-generated file, do not edit by hand. SZ metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_SZ = PhoneMetadata(id='SZ', country_code=268, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='0800\\d{4}|(?:[237]\\d|900)\\d{6}', possible_length=(8, 9)),
    fixed_line=PhoneNumberDesc(national_number_pattern='[23][2-5]\\d{6}', example_number='22171234', possible_length=(8,)),
    mobile=PhoneNumberDesc(national_number_pattern='7[6-9]\\d{6}', example_number='76123456', possible_length=(8,)),
    toll_free=PhoneNumberDesc(national_number_pattern='0800\\d{4}', example_number='08001234', possible_length=(8,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='900\\d{6}', example_number='900012345', possible_length=(9,)),
    voip=PhoneNumberDesc(national_number_pattern='70\\d{6}', example_number='70012345', possible_length=(8,)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='0800\\d{4}', possible_length=(8,)),
    number_format=[NumberFormat(pattern='(\\d{4})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['[0237]']),
        NumberFormat(pattern='(\\d{5})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['9'])])



"""Auto-generated file, do not edit by hand. IO metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_IO = PhoneMetadata(id='IO', country_code=246, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='3\\d{6}', possible_length=(7,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='37\\d{5}', example_number='3709100', possible_length=(7,)),
    mobile=PhoneNumberDesc(national_number_pattern='38\\d{5}', example_number='3801234', possible_length=(7,)),
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['3'])])



"""Auto-generated file, do not edit by hand. AS metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_AS = PhoneMetadata(id='AS', country_code=1, international_prefix='011',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[58]\\d\\d|684|900)\\d{7}', possible_length=(10,), possible_length_local_only=(7,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='6846(?:22|33|44|55|77|88|9[19])\\d{4}', example_number='6846221234', possible_length=(10,), possible_length_local_only=(7,)),
    mobile=PhoneNumberDesc(national_number_pattern='684(?:2(?:5[2468]|72)|7(?:3[13]|70))\\d{4}', example_number='6847331234', possible_length=(10,), possible_length_local_only=(7,)),
    toll_free=PhoneNumberDesc(national_number_pattern='8(?:00|33|44|55|66|77|88)[2-9]\\d{6}', example_number='8002123456', possible_length=(10,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='900[2-9]\\d{6}', example_number='9002123456', possible_length=(10,)),
    personal_number=PhoneNumberDesc(national_number_pattern='5(?:00|2[12]|33|44|66|77|88)[2-9]\\d{6}', example_number='5002345678', possible_length=(10,)),
    national_prefix='1',
    national_prefix_for_parsing='1|([267]\\d{6})$',
    national_prefix_transform_rule='684\\1',
    leading_digits='684')



"""Auto-generated file, do not edit by hand. GB metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_GB = PhoneMetadata(id='GB', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='[1-46-9]\\d{2,5}', possible_length=(3, 4, 5, 6)),
    toll_free=PhoneNumberDesc(national_number_pattern='1(?:05|1(?:2|6\\d{3})|7[56]\\d|8000)|2(?:20\\d|48)|4444|999', example_number='105', possible_length=(3, 4, 5, 6)),
    emergency=PhoneNumberDesc(national_number_pattern='112|999', example_number='112', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='1(?:0[015]|1(?:[12]|6(?:000|1(?:11|23))|8\\d{3})|2(?:[1-3]|50)|33|4(?:1|7\\d)|571|7(?:0\\d|[56]0)|800\\d|9[15])|2(?:0202|1300|2(?:02|11)|3(?:02|336|45)|4(?:25|8))|3[13]3|4(?:0[02]|35[01]|44[45]|5\\d)|(?:[68]\\d|7[089])\\d{3}|15\\d|2[02]2|650|789|9(?:01|99)', example_number='100', possible_length=(3, 4, 5, 6)),
    carrier_specific=PhoneNumberDesc(national_number_pattern='1(?:(?:25|7[56])\\d|571)|2(?:02(?:\\d{2})?|[13]3\\d\\d|48)|4444|901', example_number='202', possible_length=(3, 4, 5)),
    sms_services=PhoneNumberDesc(national_number_pattern='(?:125|2(?:020|13\\d)|(?:7[089]|8[01])\\d\\d)\\d', example_number='1250', possible_length=(4, 5)),
    short_data=True)



"""Auto-generated file, do not edit by hand. TW metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_TW = PhoneMetadata(id='TW', country_code=886, international_prefix='0(?:0[25-79]|19)',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[24589]|7\\d)\\d{8}|[2-8]\\d{7}|2\\d{6}', possible_length=(7, 8, 9, 10)),
    fixed_line=PhoneNumberDesc(national_number_pattern='24\\d{6,7}|8(?:2(?:3\\d|66)|36[24-9])\\d{4}|(?:2[235-8]\\d|3[2-9]|4(?:[239]\\d|[78])|5[2-8]|6[235-79]|7[1-9]|8[7-9])\\d{6}', example_number='221234567', possible_length=(8, 9)),
    mobile=PhoneNumberDesc(national_number_pattern='9[0-8]\\d{7}', example_number='912345678', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='80[0-79]\\d{6}', example_number='800123456', possible_length=(9,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='20(?:[013-9]\\d\\d|2)\\d{4}', example_number='203123456', possible_length=(7, 9)),
    personal_number=PhoneNumberDesc(national_number_pattern='99\\d{7}', example_number='990123456', possible_length=(9,)),
    voip=PhoneNumberDesc(national_number_pattern='70\\d{8}', example_number='7012345678', possible_length=(10,)),
    uan=PhoneNumberDesc(national_number_pattern='50[0-46-9]\\d{6}', example_number='500123456', possible_length=(9,)),
    national_prefix='0',
    preferred_extn_prefix='#',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{2})(\\d)(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['202'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d)(\\d{3,4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[25][2-8]|[346]|7[1-9]|8[237-9]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[258]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['9'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['7'], national_prefix_formatting_rule='0\\1')],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. 372 metadata"""
from ..phonemetadata import NumberFormat

PHONE_ALT_FORMAT_372 = [NumberFormat(pattern='(\\d)(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['6']), NumberFormat(pattern='(\\d{2})(\\d{2})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['[4-79]']), NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{2})', format='\\1 \\2 \\3', leading_digits_pattern=['[4-79]'])]



"""Auto-generated file, do not edit by hand. PG metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_PG = PhoneMetadata(id='PG', country_code=675, international_prefix='00|140[1-3]',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:180|[78]\\d{3})\\d{4}|(?:[2-589]\\d|64)\\d{5}', possible_length=(7, 8)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:64[1-9]|7730|85[02-46-9])\\d{4}|(?:3[0-2]|4[257]|5[34]|77[0-24]|9[78])\\d{5}', example_number='3123456', possible_length=(7, 8)),
    mobile=PhoneNumberDesc(national_number_pattern='775\\d{5}|(?:7[0-689]|81)\\d{6}', example_number='70123456', possible_length=(8,)),
    toll_free=PhoneNumberDesc(national_number_pattern='180\\d{4}', example_number='1801234', possible_length=(7,)),
    voip=PhoneNumberDesc(national_number_pattern='2(?:0[0-47]|7[568])\\d{4}', example_number='2751234', possible_length=(7,)),
    preferred_international_prefix='00',
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['18|[2-69]|85']),
        NumberFormat(pattern='(\\d{4})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['[78]'])])



"""Auto-generated file, do not edit by hand. VI metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_VI = PhoneMetadata(id='VI', country_code=1, international_prefix='011',
    general_desc=PhoneNumberDesc(national_number_pattern='[58]\\d{9}|(?:34|90)0\\d{7}', possible_length=(10,), possible_length_local_only=(7,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='340(?:2(?:01|2[06-8]|44|77)|3(?:32|44)|4(?:22|7[34])|5(?:1[34]|55)|6(?:26|4[23]|77|9[023])|7(?:1[2-57-9]|27|7\\d)|884|998)\\d{4}', example_number='3406421234', possible_length=(10,), possible_length_local_only=(7,)),
    mobile=PhoneNumberDesc(national_number_pattern='340(?:2(?:01|2[06-8]|44|77)|3(?:32|44)|4(?:22|7[34])|5(?:1[34]|55)|6(?:26|4[23]|77|9[023])|7(?:1[2-57-9]|27|7\\d)|884|998)\\d{4}', example_number='3406421234', possible_length=(10,), possible_length_local_only=(7,)),
    toll_free=PhoneNumberDesc(national_number_pattern='8(?:00|33|44|55|66|77|88)[2-9]\\d{6}', example_number='8002345678', possible_length=(10,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='900[2-9]\\d{6}', example_number='9002345678', possible_length=(10,)),
    personal_number=PhoneNumberDesc(national_number_pattern='5(?:00|2[12]|33|44|66|77|88)[2-9]\\d{6}', example_number='5002345678', possible_length=(10,)),
    national_prefix='1',
    national_prefix_for_parsing='1|([2-9]\\d{6})$',
    national_prefix_transform_rule='340\\1',
    leading_digits='340')



"""Auto-generated file, do not edit by hand. PK metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_PK = PhoneMetadata(id='PK', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='1\\d{1,3}', possible_length=(2, 3, 4)),
    toll_free=PhoneNumberDesc(national_number_pattern='1(?:1(?:2\\d?|5)|[56])', example_number='15', possible_length=(2, 3, 4)),
    emergency=PhoneNumberDesc(national_number_pattern='1(?:1(?:22?|5)|[56])', example_number='15', possible_length=(2, 3, 4)),
    short_code=PhoneNumberDesc(national_number_pattern='1(?:1(?:22?|5)|[56])', example_number='15', possible_length=(2, 3, 4)),
    short_data=True)



"""Auto-generated file, do not edit by hand. LI metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_LI = PhoneMetadata(id='LI', country_code=423, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='90\\d{5}|(?:[2378]|6\\d\\d)\\d{6}', possible_length=(7, 9)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:2(?:01|1[27]|22|3\\d|6[02-578]|96)|3(?:33|40|7[0135-7]|8[048]|9[0269]))\\d{4}', example_number='2345678', possible_length=(7,)),
    mobile=PhoneNumberDesc(national_number_pattern='756\\d{4}|(?:6(?:499|5[0-3]\\d|6(?:0[0-7]|10|2[06-9]|39))|7[37-9])\\d{5}', example_number='660234567', possible_length=(7, 9)),
    toll_free=PhoneNumberDesc(national_number_pattern='80(?:02[28]|9\\d\\d)\\d\\d', example_number='8002222', possible_length=(7,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='90(?:02[258]|1(?:23|3[14])|66[136])\\d\\d', example_number='9002222', possible_length=(7,)),
    uan=PhoneNumberDesc(national_number_pattern='870(?:28|87)\\d\\d', example_number='8702812', possible_length=(7,)),
    voicemail=PhoneNumberDesc(national_number_pattern='697(?:56|[78]\\d)\\d{4}', example_number='697861234', possible_length=(9,)),
    national_prefix='0',
    national_prefix_for_parsing='0|(10(?:01|20|66))',
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{2})(\\d{2})', format='\\1 \\2 \\3', leading_digits_pattern=['[237-9]'], domestic_carrier_code_formatting_rule='$CC \\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['69'], domestic_carrier_code_formatting_rule='$CC \\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['6'], domestic_carrier_code_formatting_rule='$CC \\1')])



"""Auto-generated file, do not edit by hand. NG metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_NG = PhoneMetadata(id='NG', country_code=234, international_prefix='009',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[124-7]|9\\d{3})\\d{6}|[1-9]\\d{7}|[78]\\d{9,13}', possible_length=(7, 8, 10, 11, 12, 13, 14), possible_length_local_only=(5, 6)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:(?:[1-356]\\d|4[02-8]|7[0-79]|8[2-9])\\d|9(?:0[3-9]|[1-9]\\d))\\d{5}|(?:[12]\\d|4[147]|5[14579]|6[1578]|7[0-3578])\\d{5}', example_number='18040123', possible_length=(7, 8), possible_length_local_only=(5, 6)),
    mobile=PhoneNumberDesc(national_number_pattern='(?:707[0-3]|8(?:01|19)[01])\\d{6}|(?:70[1-689]|8(?:0[2-9]|1[0-8])|90[1-35-9])\\d{7}', example_number='8021234567', possible_length=(10,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800\\d{7,11}', example_number='80017591759', possible_length=(10, 11, 12, 13, 14)),
    uan=PhoneNumberDesc(national_number_pattern='700\\d{7,11}', example_number='7001234567', possible_length=(10, 11, 12, 13, 14)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{2})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['78'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d)(\\d{3})(\\d{3,4})', format='\\1 \\2 \\3', leading_digits_pattern=['[12]|9(?:0[3-9]|[1-9])'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{2,3})', format='\\1 \\2 \\3', leading_digits_pattern=['[3-7]|8[2-9]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3,4})', format='\\1 \\2 \\3', leading_digits_pattern=['[7-9]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{4})(\\d{4,5})', format='\\1 \\2 \\3', leading_digits_pattern=['[78]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{5})(\\d{5,6})', format='\\1 \\2 \\3', leading_digits_pattern=['[78]'], national_prefix_formatting_rule='0\\1')],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. CR metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_CR = PhoneMetadata(id='CR', country_code=506, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:8\\d|90)\\d{8}|[24-8]\\d{7}', possible_length=(8, 10)),
    fixed_line=PhoneNumberDesc(national_number_pattern='210[7-9]\\d{4}|2(?:[024-7]\\d|1[1-9])\\d{5}', example_number='22123456', possible_length=(8,)),
    mobile=PhoneNumberDesc(national_number_pattern='6500[01]\\d{3}|5(?:0[01]|7[0-3])\\d{5}|(?:6[0-4]|7[0-3]|8[3-9])\\d{6}', example_number='83123456', possible_length=(8,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800\\d{7}', example_number='8001234567', possible_length=(10,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='90[059]\\d{7}', example_number='9001234567', possible_length=(10,)),
    voip=PhoneNumberDesc(national_number_pattern='(?:210[0-6]|4\\d{3}|5100)\\d{4}', example_number='40001234', possible_length=(8,)),
    national_prefix_for_parsing='(19(?:0[0-2468]|1[09]|20|66|77|99))',
    number_format=[NumberFormat(pattern='(\\d{4})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['[24-7]|8[3-9]'], domestic_carrier_code_formatting_rule='$CC \\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{4})', format='\\1-\\2-\\3', leading_digits_pattern=['[89]'], domestic_carrier_code_formatting_rule='$CC \\1')])



"""Auto-generated file, do not edit by hand. DJ metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_DJ = PhoneMetadata(id='DJ', country_code=253, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:2\\d|77)\\d{6}', possible_length=(8,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='2(?:1[2-5]|7[45])\\d{5}', example_number='21360003', possible_length=(8,)),
    mobile=PhoneNumberDesc(national_number_pattern='77\\d{6}', example_number='77831001', possible_length=(8,)),
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{2})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['[27]'])])



"""Auto-generated file, do not edit by hand. SK metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_SK = PhoneMetadata(id='SK', country_code=421, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='[2-689]\\d{8}|[2-59]\\d{6}|[2-5]\\d{5}', possible_length=(6, 7, 9)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:2(?:16|[2-9]\\d{3})|[3-5][1-8]\\d{3})\\d{4}|(?:2|[3-5][1-8])1[67]\\d{3}|[3-5][1-8]16\\d\\d', example_number='221234567', possible_length=(6, 7, 9)),
    mobile=PhoneNumberDesc(national_number_pattern='909[1-9]\\d{5}|9(?:0[1-8]|1[0-24-9]|[45]\\d)\\d{6}', example_number='912123456', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800\\d{6}', example_number='800123456', possible_length=(9,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='9(?:00|[78]\\d)\\d{6}', example_number='900123456', possible_length=(9,)),
    shared_cost=PhoneNumberDesc(national_number_pattern='8[5-9]\\d{7}', example_number='850123456', possible_length=(9,)),
    voip=PhoneNumberDesc(national_number_pattern='6(?:02|5[0-4]|9[0-6])\\d{6}', example_number='690123456', possible_length=(9,)),
    pager=PhoneNumberDesc(national_number_pattern='9090\\d{3}', example_number='9090123', possible_length=(7,)),
    uan=PhoneNumberDesc(national_number_pattern='96\\d{7}', example_number='961234567', possible_length=(9,)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='9090\\d{3}|(?:602|8(?:00|[5-9]\\d)|9(?:00|[78]\\d))\\d{6}', possible_length=(7, 9)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d)(\\d{2})(\\d{3,4})', format='\\1 \\2 \\3', leading_digits_pattern=['21'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{2})(\\d{2,3})', format='\\1 \\2 \\3', leading_digits_pattern=['[3-5][1-8]1', '[3-5][1-8]1[67]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{4})(\\d{3})', format='\\1 \\2', leading_digits_pattern=['909', '9090'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d)(\\d{3})(\\d{3})(\\d{2})', format='\\1/\\2 \\3 \\4', leading_digits_pattern=['2'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['[689]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{2})(\\d{2})', format='\\1/\\2 \\3 \\4', leading_digits_pattern=['[3-5]'], national_prefix_formatting_rule='0\\1')],
    intl_number_format=[NumberFormat(pattern='(\\d)(\\d{2})(\\d{3,4})', format='\\1 \\2 \\3', leading_digits_pattern=['21']),
        NumberFormat(pattern='(\\d{2})(\\d{2})(\\d{2,3})', format='\\1 \\2 \\3', leading_digits_pattern=['[3-5][1-8]1', '[3-5][1-8]1[67]']),
        NumberFormat(pattern='(\\d)(\\d{3})(\\d{3})(\\d{2})', format='\\1/\\2 \\3 \\4', leading_digits_pattern=['2']),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['[689]']),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{2})(\\d{2})', format='\\1/\\2 \\3 \\4', leading_digits_pattern=['[3-5]'])],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. GI metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_GI = PhoneMetadata(id='GI', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='[158]\\d{2,5}', possible_length=(3, 4, 5, 6)),
    toll_free=PhoneNumberDesc(national_number_pattern='1(?:00|1[25]|23|4(?:1|7\\d)|5[15]|9[02-49])|555|(?:116\\d|80)\\d\\d', example_number='100', possible_length=(3, 4, 6)),
    premium_rate=PhoneNumberDesc(national_number_pattern='8[1-69]\\d\\d', example_number='8100', possible_length=(4,)),
    emergency=PhoneNumberDesc(national_number_pattern='1(?:12|9[09])', example_number='112', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='1(?:00|1(?:[25]|6(?:00[06]|1(?:1[17]|23))|8\\d\\d)|23|4(?:1|7[014])|5[015]|9[02-49])|555|8[0-79]\\d\\d|8(?:00|4[0-2]|8[0-589])', example_number='100', possible_length=(3, 4, 5, 6)),
    standard_rate=PhoneNumberDesc(national_number_pattern='150|87\\d\\d', example_number='150', possible_length=(3, 4)),
    carrier_specific=PhoneNumberDesc(national_number_pattern='1(?:00|1(?:5|8\\d\\d)|23|51|9[2-4])|555|8(?:00|4[0-2]|8[0-589])', example_number='100', possible_length=(3, 5)),
    short_data=True)



"""Auto-generated file, do not edit by hand. BE metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_BE = PhoneMetadata(id='BE', country_code=32, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='4\\d{8}|[1-9]\\d{7}', possible_length=(8, 9)),
    fixed_line=PhoneNumberDesc(national_number_pattern='80[2-8]\\d{5}|(?:1[0-69]|[23][2-8]|4[23]|5\\d|6[013-57-9]|71|8[1-79]|9[2-4])\\d{6}', example_number='12345678', possible_length=(8,)),
    mobile=PhoneNumberDesc(national_number_pattern='4(?:5[56]|6[0135-8]|[79]\\d|8[3-9])\\d{6}', example_number='470123456', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800[1-9]\\d{4}', example_number='80012345', possible_length=(8,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='(?:70(?:2[0-57]|3[0457]|44|69|7[0579])|90(?:0[0-35-8]|1[36]|2[0-3568]|3[0135689]|4[2-68]|5[1-68]|6[0-378]|7[23568]|9[34679]))\\d{4}', example_number='90012345', possible_length=(8,)),
    shared_cost=PhoneNumberDesc(national_number_pattern='7879\\d{4}', example_number='78791234', possible_length=(8,)),
    uan=PhoneNumberDesc(national_number_pattern='78(?:0[57]|1[0458]|2[25]|3[5-8]|48|[56]0|7[078])\\d{4}', example_number='78102345', possible_length=(8,)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{2})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['(?:80|9)0'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d)(\\d{3})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['[239]|4[23]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{2})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['[15-8]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{2})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['4'], national_prefix_formatting_rule='0\\1')],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. US metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_US = PhoneMetadata(id='US', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='[1-9]\\d{2,5}', possible_length=(3, 4, 5, 6)),
    toll_free=PhoneNumberDesc(national_number_pattern='112|[69]11', example_number='112', possible_length=(3,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='24280|(?:381|968)35|4(?:3355|7553|8221)|5(?:(?:489|934)2|5928)|72078|(?:323|960)40|(?:276|414)63|(?:2(?:520|744)|7390|9968)9|(?:693|732|976)88|(?:3(?:556|825)|5294|8623|9729)4|(?:3378|4136|7642|8961|9979)6|(?:4(?:6(?:15|32)|827)|(?:591|720)8|9529)7', example_number='24280', possible_length=(5,)),
    emergency=PhoneNumberDesc(national_number_pattern='112|911', example_number='112', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='11(?:2|5[1-47]|[68]\\d|7[0-57]|98)|[2-9]\\d{3,5}|[2-9]11', example_number='112', possible_length=(3, 4, 5, 6)),
    standard_rate=PhoneNumberDesc(national_number_pattern='2(?:3333|(?:4224|7562|900)2|56447|6688)|3(?:1010|2665|7404)|40404|560560|6(?:0060|22639|5246|7622)|7(?:0701|3822|4666)|8(?:(?:3825|7226)5|4816)|99099', example_number='23333', possible_length=(5, 6)),
    carrier_specific=PhoneNumberDesc(national_number_pattern='336\\d\\d|[2-9]\\d{3}|[2356]11', example_number='211', possible_length=(3, 4, 5)),
    sms_services=PhoneNumberDesc(national_number_pattern='[2-9]\\d{4,5}', example_number='20000', possible_length=(5, 6)),
    short_data=True)



"""Auto-generated file, do not edit by hand. QA metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_QA = PhoneMetadata(id='QA', country_code=974, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='800\\d{4}|(?:2|[3-7]\\d)\\d{6}', possible_length=(7, 8)),
    fixed_line=PhoneNumberDesc(national_number_pattern='4[04]\\d{6}', example_number='44123456', possible_length=(8,)),
    mobile=PhoneNumberDesc(national_number_pattern='[35-7]\\d{7}', example_number='33123456', possible_length=(8,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800\\d{4}', example_number='8001234', possible_length=(7,)),
    pager=PhoneNumberDesc(national_number_pattern='2(?:[12]\\d|61)\\d{4}', example_number='2123456', possible_length=(7,)),
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['2[126]|8']),
        NumberFormat(pattern='(\\d{4})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['[3-7]'])],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. EC metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_EC = PhoneMetadata(id='EC', country_code=593, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='1800\\d{6,7}|(?:[2-7]|9\\d)\\d{7}', possible_length=(8, 9, 10, 11), possible_length_local_only=(7,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='[2-7][2-7]\\d{6}', example_number='22123456', possible_length=(8,), possible_length_local_only=(7,)),
    mobile=PhoneNumberDesc(national_number_pattern='964[0-2]\\d{5}|9(?:39|[57][89]|6[0-37-9]|[89]\\d)\\d{6}', example_number='991234567', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='1800\\d{6,7}', example_number='18001234567', possible_length=(10, 11)),
    voip=PhoneNumberDesc(national_number_pattern='[2-7]890\\d{4}', example_number='28901234', possible_length=(8,)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{4})', format='\\1-\\2', leading_digits_pattern=['[2-7]']),
        NumberFormat(pattern='(\\d)(\\d{3})(\\d{4})', format='\\1 \\2-\\3', leading_digits_pattern=['[2-7]'], national_prefix_formatting_rule='(0\\1)'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['9'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{4})(\\d{3})(\\d{3,4})', format='\\1 \\2 \\3', leading_digits_pattern=['1'])],
    intl_number_format=[NumberFormat(pattern='(\\d)(\\d{3})(\\d{4})', format='\\1-\\2-\\3', leading_digits_pattern=['[2-7]']),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['9']),
        NumberFormat(pattern='(\\d{4})(\\d{3})(\\d{3,4})', format='\\1 \\2 \\3', leading_digits_pattern=['1'])],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. GH metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_GH = PhoneMetadata(id='GH', country_code=233, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[235]\\d{3}|800)\\d{5}', possible_length=(8, 9), possible_length_local_only=(7,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='3(?:[167]2[0-6]|22[0-5]|32[0-3]|4(?:2[013-9]|3[01])|52[0-7]|82[0-2])\\d{5}|3(?:[0-8]8|9[28])0\\d{5}|3(?:0[237]|[1-9]7)\\d{6}', example_number='302345678', possible_length=(9,), possible_length_local_only=(7,)),
    mobile=PhoneNumberDesc(national_number_pattern='56[01]\\d{6}|(?:2[0346-8]|5[0457])\\d{7}', example_number='231234567', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800\\d{5}', example_number='80012345', possible_length=(8,)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='800\\d{5}', possible_length=(8,)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['[237]|80']),
        NumberFormat(pattern='(\\d{3})(\\d{5})', format='\\1 \\2', leading_digits_pattern=['8'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[235]'], national_prefix_formatting_rule='0\\1')],
    intl_number_format=[NumberFormat(pattern='(\\d{3})(\\d{5})', format='\\1 \\2', leading_digits_pattern=['8']),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[235]'])],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. KZ metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_KZ = PhoneMetadata(id='KZ', country_code=7, international_prefix='810',
    general_desc=PhoneNumberDesc(national_number_pattern='33622\\d{5}|(?:7\\d|80)\\d{8}', possible_length=(10,), possible_length_local_only=(5, 6)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:33622|7(?:1(?:0(?:[23]\\d|4[0-3]|59|63)|1(?:[23]\\d|4[0-79]|59)|2(?:[23]\\d|59)|3(?:2\\d|3[0-79]|4[0-35-9]|59)|4(?:[24]\\d|3[013-9]|5[1-9])|5(?:2\\d|3[1-9]|4[0-7]|59)|6(?:[2-4]\\d|5[19]|61)|72\\d|8(?:[27]\\d|3[1-46-9]|4[0-5]))|2(?:1(?:[23]\\d|4[46-9]|5[3469])|2(?:2\\d|3[0679]|46|5[12679])|3(?:[2-4]\\d|5[139])|4(?:2\\d|3[1-35-9]|59)|5(?:[23]\\d|4[0-246-8]|59|61)|6(?:2\\d|3[1-9]|4[0-4]|59)|7(?:[2379]\\d|40|5[279])|8(?:[23]\\d|4[0-3]|59)|9(?:2\\d|3[124578]|59))))\\d{5}', example_number='7123456789', possible_length=(10,), possible_length_local_only=(5, 6)),
    mobile=PhoneNumberDesc(national_number_pattern='7(?:0[0-2578]|47|6[02-4]|7[15-8]|85)\\d{7}', example_number='7710009998', possible_length=(10,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800\\d{7}', example_number='8001234567', possible_length=(10,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='809\\d{7}', example_number='8091234567', possible_length=(10,)),
    personal_number=PhoneNumberDesc(national_number_pattern='808\\d{7}', example_number='8081234567', possible_length=(10,)),
    voip=PhoneNumberDesc(national_number_pattern='751\\d{7}', example_number='7511234567', possible_length=(10,)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='751\\d{7}', possible_length=(10,)),
    preferred_international_prefix='8~10',
    national_prefix='8',
    national_prefix_for_parsing='8',
    leading_digits='33|7')



"""Auto-generated file, do not edit by hand. AX metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_AX = PhoneMetadata(id='AX', country_code=358, international_prefix='00|99(?:[01469]|5(?:[14]1|3[23]|5[59]|77|88|9[09]))',
    general_desc=PhoneNumberDesc(national_number_pattern='2\\d{4,9}|35\\d{4,5}|(?:60\\d\\d|800)\\d{4,6}|(?:[147]\\d|3[0-46-9]|50)\\d{4,8}', possible_length=(5, 6, 7, 8, 9, 10)),
    fixed_line=PhoneNumberDesc(national_number_pattern='18[1-8]\\d{3,6}', example_number='181234567', possible_length=(6, 7, 8, 9)),
    mobile=PhoneNumberDesc(national_number_pattern='(?:4[0-8]|50)\\d{4,8}', example_number='412345678', possible_length=(6, 7, 8, 9, 10)),
    toll_free=PhoneNumberDesc(national_number_pattern='800\\d{4,6}', example_number='800123456', possible_length=(7, 8, 9)),
    premium_rate=PhoneNumberDesc(national_number_pattern='[67]00\\d{5,6}', example_number='600123456', possible_length=(8, 9)),
    uan=PhoneNumberDesc(national_number_pattern='(?:10|[23][09])\\d{4,8}|60(?:[12]\\d{5,6}|6\\d{7})|7(?:(?:1|3\\d)\\d{7}|5[03-9]\\d{3,7})|20[2-59]\\d\\d', example_number='10112345', possible_length=(5, 6, 7, 8, 9, 10)),
    preferred_international_prefix='00',
    national_prefix='0',
    national_prefix_for_parsing='0',
    leading_digits='18')



"""Auto-generated file, do not edit by hand. CL metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_CL = PhoneMetadata(id='CL', country_code=56, international_prefix='(?:0|1(?:1[0-69]|2[0-57]|5[13-58]|69|7[0167]|8[018]))0',
    general_desc=PhoneNumberDesc(national_number_pattern='12300\\d{6}|6\\d{9,10}|[2-9]\\d{8}', possible_length=(9, 10, 11)),
    fixed_line=PhoneNumberDesc(national_number_pattern='21962\\d{4}|(?:232[0-46-8]|80[1-9]\\d)\\d{5}|(?:22|3[2-5]|[47][1-35]|5[1-3578]|6[13-57]|8[1-9]|9[2-9])\\d{7}', example_number='221234567', possible_length=(9,)),
    mobile=PhoneNumberDesc(national_number_pattern='21962\\d{4}|(?:232[0-46-8]|80[1-9]\\d)\\d{5}|(?:22|3[2-5]|[47][1-35]|5[1-3578]|6[13-57]|8[1-9]|9[2-9])\\d{7}', example_number='221234567', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='(?:123|8)00\\d{6}', example_number='800123456', possible_length=(9, 11)),
    shared_cost=PhoneNumberDesc(national_number_pattern='600\\d{7,8}', example_number='6001234567', possible_length=(10, 11)),
    voip=PhoneNumberDesc(national_number_pattern='44\\d{7}', example_number='441234567', possible_length=(9,)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='600\\d{7,8}', possible_length=(10, 11)),
    number_format=[NumberFormat(pattern='(\\d{4})', format='\\1', leading_digits_pattern=['1(?:[03-589]|21)|[29]0|78']),
        NumberFormat(pattern='(\\d{5})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['21'], national_prefix_formatting_rule='(\\1)'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['44']),
        NumberFormat(pattern='(\\d)(\\d{4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['2[23]'], national_prefix_formatting_rule='(\\1)'),
        NumberFormat(pattern='(\\d)(\\d{4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['9[2-9]']),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['3[2-5]|[47]|5[1-3578]|6[13-57]|8(?:0[1-9]|[1-9])'], national_prefix_formatting_rule='(\\1)'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3,4})', format='\\1 \\2 \\3', leading_digits_pattern=['60|8']),
        NumberFormat(pattern='(\\d{4})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['1']),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{2})(\\d{3})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['60'])],
    intl_number_format=[NumberFormat(pattern='(\\d{5})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['21']),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['44']),
        NumberFormat(pattern='(\\d)(\\d{4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['2[23]']),
        NumberFormat(pattern='(\\d)(\\d{4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['9[2-9]']),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['3[2-5]|[47]|5[1-3578]|6[13-57]|8(?:0[1-9]|[1-9])']),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3,4})', format='\\1 \\2 \\3', leading_digits_pattern=['60|8']),
        NumberFormat(pattern='(\\d{4})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['1']),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{2})(\\d{3})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['60'])],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. 27 metadata"""
from ..phonemetadata import NumberFormat

PHONE_ALT_FORMAT_27 = [NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['86[1-9]'])]



"""Auto-generated file, do not edit by hand. SG metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_SG = PhoneMetadata(id='SG', country_code=65, international_prefix='0[0-3]\\d',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:(?:1\\d|8)\\d\\d|7000)\\d{7}|[3689]\\d{7}', possible_length=(8, 10, 11)),
    fixed_line=PhoneNumberDesc(national_number_pattern='6[1-9]\\d{6}', example_number='61234567', possible_length=(8,)),
    mobile=PhoneNumberDesc(national_number_pattern='(?:8[1-8]|9[0-8])\\d{6}', example_number='81234567', possible_length=(8,)),
    toll_free=PhoneNumberDesc(national_number_pattern='(?:18|8)00\\d{7}', example_number='18001234567', possible_length=(10, 11)),
    premium_rate=PhoneNumberDesc(national_number_pattern='1900\\d{7}', example_number='19001234567', possible_length=(11,)),
    voip=PhoneNumberDesc(national_number_pattern='3[12]\\d{6}', example_number='31234567', possible_length=(8,)),
    uan=PhoneNumberDesc(national_number_pattern='7000\\d{7}', example_number='70001234567', possible_length=(11,)),
    number_format=[NumberFormat(pattern='(\\d{4,5})', format='\\1', leading_digits_pattern=['1[0135-7]|77']),
        NumberFormat(pattern='(\\d{4})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['[369]|8[1-8]']),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['8']),
        NumberFormat(pattern='(\\d{4})(\\d{4})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['7']),
        NumberFormat(pattern='(\\d{4})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['1'])],
    intl_number_format=[NumberFormat(pattern='(\\d{4})(\\d{4})', format='\\1 \\2', leading_digits_pattern=['[369]|8[1-8]']),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['8']),
        NumberFormat(pattern='(\\d{4})(\\d{4})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['7']),
        NumberFormat(pattern='(\\d{4})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['1'])],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. UA metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_UA = PhoneMetadata(id='UA', country_code=380, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='[89]\\d{9}|[3-9]\\d{8}', possible_length=(9, 10), possible_length_local_only=(5, 6, 7)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:3[1-8]|4[13-8]|5[1-7]|6[12459])\\d{7}', example_number='311234567', possible_length=(9,), possible_length_local_only=(5, 6, 7)),
    mobile=PhoneNumberDesc(national_number_pattern='(?:50|6[36-8]|7[1-3]|9[1-9])\\d{7}', example_number='501234567', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800[1-8]\\d{5,6}', example_number='800123456', possible_length=(9, 10)),
    premium_rate=PhoneNumberDesc(national_number_pattern='900[239]\\d{5,6}', example_number='900212345', possible_length=(9, 10)),
    voip=PhoneNumberDesc(national_number_pattern='89[1-579]\\d{6}', example_number='891234567', possible_length=(9,)),
    preferred_international_prefix='0~0',
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['6[12][29]|(?:3[1-8]|4[136-8]|5[12457]|6[49])2|(?:56|65)[24]', '6[12][29]|(?:35|4[1378]|5[12457]|6[49])2|(?:56|65)[24]|(?:3[1-46-8]|46)2[013-9]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['4[45][0-5]|5(?:0|6[37])|6(?:[12][018]|[36-8])|7|89|9[1-9]|(?:48|57)[0137-9]', '4[45][0-5]|5(?:0|6(?:3[14-7]|7))|6(?:[12][018]|[36-8])|7|89|9[1-9]|(?:48|57)[0137-9]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{4})(\\d{5})', format='\\1 \\2', leading_digits_pattern=['[3-6]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3,4})', format='\\1 \\2 \\3', leading_digits_pattern=['[89]'], national_prefix_formatting_rule='0\\1')])



"""Auto-generated file, do not edit by hand. KI metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_KI = PhoneMetadata(id='KI', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='[17]\\d{2,3}', possible_length=(3, 4)),
    toll_free=PhoneNumberDesc(national_number_pattern='19[2-5]', example_number='192', possible_length=(3,)),
    emergency=PhoneNumberDesc(national_number_pattern='19[2-5]', example_number='192', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='1(?:05[0-259]|88|9[2-5])|777|10[0-8]', example_number='100', possible_length=(3, 4)),
    standard_rate=PhoneNumberDesc(national_number_pattern='103', example_number='103', possible_length=(3,)),
    short_data=True)



"""Auto-generated file, do not edit by hand. SI metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_SI = PhoneMetadata(id='SI', country_code=386, international_prefix='00|10(?:22|66|88|99)',
    general_desc=PhoneNumberDesc(national_number_pattern='[1-7]\\d{7}|8\\d{4,7}|90\\d{4,6}', possible_length=(5, 6, 7, 8), possible_length_local_only=(7,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:[1-357][2-8]|4[24-8])\\d{6}', example_number='12345678', possible_length=(8,), possible_length_local_only=(7,)),
    mobile=PhoneNumberDesc(national_number_pattern='6(?:5(?:1\\d|55|[67]0)|9(?:10|[69]\\d))\\d{4}|(?:[37][01]|4[0139]|51|6[48])\\d{6}', example_number='31234567', possible_length=(8,)),
    toll_free=PhoneNumberDesc(national_number_pattern='80\\d{4,6}', example_number='80123456', possible_length=(6, 7, 8)),
    premium_rate=PhoneNumberDesc(national_number_pattern='89[1-3]\\d{2,5}|90\\d{4,6}', example_number='90123456', possible_length=(5, 6, 7, 8)),
    voip=PhoneNumberDesc(national_number_pattern='(?:59\\d\\d|8(?:1(?:[67]\\d|8[01389])|2(?:0\\d|2[0378]|8[0-2489])|3[389]\\d))\\d{4}', example_number='59012345', possible_length=(8,)),
    preferred_international_prefix='00',
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{3,6})', format='\\1 \\2', leading_digits_pattern=['8[09]|9'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{5})', format='\\1 \\2', leading_digits_pattern=['59|8'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['[37][01]|4[0139]|51|6'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d)(\\d{3})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['[1-57]'], national_prefix_formatting_rule='(0\\1)')],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. NL metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_NL = PhoneMetadata(id='NL', country_code=31, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[124-7]\\d\\d|3(?:[02-9]\\d|1[0-8]))\\d{6}|[89]\\d{6,9}|1\\d{4,5}', possible_length=(5, 6, 7, 8, 9, 10)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:1(?:[035]\\d|1[13-578]|6[124-8]|7[24]|8[0-467])|2(?:[0346]\\d|2[2-46-9]|5[125]|9[479])|3(?:[03568]\\d|1[3-8]|2[01]|4[1-8])|4(?:[0356]\\d|1[1-368]|7[58]|8[15-8]|9[23579])|5(?:[0358]\\d|[19][1-9]|2[1-57-9]|4[13-8]|6[126]|7[0-3578])|7\\d\\d)\\d{6}', example_number='101234567', possible_length=(9,)),
    mobile=PhoneNumberDesc(national_number_pattern='6[1-58]\\d{7}', example_number='612345678', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800\\d{4,7}', example_number='8001234', possible_length=(7, 8, 9, 10)),
    premium_rate=PhoneNumberDesc(national_number_pattern='90[069]\\d{4,7}', example_number='9061234', possible_length=(7, 8, 9, 10)),
    voip=PhoneNumberDesc(national_number_pattern='(?:85|91)\\d{7}', example_number='851234567', possible_length=(9,)),
    pager=PhoneNumberDesc(national_number_pattern='66\\d{7}', example_number='662345678', possible_length=(9,)),
    uan=PhoneNumberDesc(national_number_pattern='140(?:1[035]|2[0346]|3[03568]|4[0356]|5[0358]|8[458])|(?:140(?:1[16-8]|2[259]|3[124]|4[17-9]|5[124679]|7)|8[478]\\d{6})\\d', example_number='14020', possible_length=(5, 6, 9)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='140(?:1[035]|2[0346]|3[03568]|4[0356]|5[0358]|8[458])|140(?:1[16-8]|2[259]|3[124]|4[17-9]|5[124679]|7)\\d', possible_length=(5, 6)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{4})', format='\\1', leading_digits_pattern=['1[238]|[34]']),
        NumberFormat(pattern='(\\d{2})(\\d{3,4})', format='\\1 \\2', leading_digits_pattern=['14']),
        NumberFormat(pattern='(\\d{6})', format='\\1', leading_digits_pattern=['1']),
        NumberFormat(pattern='(\\d{3})(\\d{4,7})', format='\\1 \\2', leading_digits_pattern=['[89]0'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{7})', format='\\1 \\2', leading_digits_pattern=['66'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d)(\\d{8})', format='\\1 \\2', leading_digits_pattern=['6'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['1[16-8]|2[259]|3[124]|4[17-9]|5[124679]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[1-57-9]'], national_prefix_formatting_rule='0\\1')],
    intl_number_format=[NumberFormat(pattern='(\\d{3})(\\d{4,7})', format='\\1 \\2', leading_digits_pattern=['[89]0']),
        NumberFormat(pattern='(\\d{2})(\\d{7})', format='\\1 \\2', leading_digits_pattern=['66']),
        NumberFormat(pattern='(\\d)(\\d{8})', format='\\1 \\2', leading_digits_pattern=['6']),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['1[16-8]|2[259]|3[124]|4[17-9]|5[124679]']),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[1-57-9]'])],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. BY metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_BY = PhoneMetadata(id='BY', country_code=375, international_prefix='810',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[12]\\d|33|44|902)\\d{7}|8(?:0[0-79]\\d{5,7}|[1-7]\\d{9})|8(?:1[0-489]|[5-79]\\d)\\d{7}|8[1-79]\\d{6,7}|8[0-79]\\d{5}|8\\d{5}', possible_length=(6, 7, 8, 9, 10, 11), possible_length_local_only=(5, 6, 7)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:1(?:5(?:1[1-5]|[24]\\d|6[2-4]|9[1-7])|6(?:[235]\\d|4[1-7])|7\\d\\d)|2(?:1(?:[246]\\d|3[0-35-9]|5[1-9])|2(?:[235]\\d|4[0-8])|3(?:[26]\\d|3[02-79]|4[024-7]|5[03-7])))\\d{5}', example_number='152450911', possible_length=(9,), possible_length_local_only=(5, 6, 7)),
    mobile=PhoneNumberDesc(national_number_pattern='(?:2(?:5[5-79]|9[1-9])|(?:33|44)\\d)\\d{6}', example_number='294911911', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800\\d{3,7}|8(?:0[13]|20\\d)\\d{7}', example_number='8011234567', possible_length=(6, 7, 8, 9, 10, 11)),
    premium_rate=PhoneNumberDesc(national_number_pattern='(?:810|902)\\d{7}', example_number='9021234567', possible_length=(10,)),
    voip=PhoneNumberDesc(national_number_pattern='249\\d{6}', example_number='249123456', possible_length=(9,)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='800\\d{3,7}|(?:8(?:0[13]|10|20\\d)|902)\\d{7}', possible_length=(6, 7, 8, 9, 10, 11)),
    preferred_international_prefix='8~10',
    national_prefix='8',
    national_prefix_for_parsing='0|80?',
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{3})', format='\\1 \\2', leading_digits_pattern=['800'], national_prefix_formatting_rule='8 \\1'),
        NumberFormat(pattern='(\\d{3})(\\d{2})(\\d{2,4})', format='\\1 \\2 \\3', leading_digits_pattern=['800'], national_prefix_formatting_rule='8 \\1'),
        NumberFormat(pattern='(\\d{4})(\\d{2})(\\d{3})', format='\\1 \\2-\\3', leading_digits_pattern=['1(?:5[169]|6[3-5]|7[179])|2(?:1[35]|2[34]|3[3-5])', '1(?:5[169]|6(?:3[1-3]|4|5[125])|7(?:1[3-9]|7[0-24-6]|9[2-7]))|2(?:1[35]|2[34]|3[3-5])'], national_prefix_formatting_rule='8 0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{2})(\\d{2})(\\d{2})', format='\\1 \\2-\\3-\\4', leading_digits_pattern=['1(?:[56]|7[467])|2[1-3]'], national_prefix_formatting_rule='8 0\\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{2})(\\d{2})', format='\\1 \\2-\\3-\\4', leading_digits_pattern=['[1-4]'], national_prefix_formatting_rule='8 0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3,4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[89]'], national_prefix_formatting_rule='8 \\1')],
    mobile_number_portable_region=True)



"""Auto-generated file, do not edit by hand. ME metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_ME = PhoneMetadata(id='ME', country_code=382, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:20|[3-79]\\d)\\d{6}|80\\d{6,7}', possible_length=(8, 9), possible_length_local_only=(6,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:20[2-8]|3(?:[0-2][2-7]|3[24-7])|4(?:0[2-467]|1[2467])|5(?:[01][2467]|2[2-467]))\\d{5}', example_number='30234567', possible_length=(8,), possible_length_local_only=(6,)),
    mobile=PhoneNumberDesc(national_number_pattern='6(?:00|3[024]|6[0-25]|[7-9]\\d)\\d{5}', example_number='67622901', possible_length=(8,)),
    toll_free=PhoneNumberDesc(national_number_pattern='80(?:[0-2578]|9\\d)\\d{5}', example_number='80080002', possible_length=(8, 9)),
    premium_rate=PhoneNumberDesc(national_number_pattern='9(?:4[1568]|5[178])\\d{5}', example_number='94515151', possible_length=(8,)),
    voip=PhoneNumberDesc(national_number_pattern='78[1-49]\\d{5}', example_number='78108780', possible_length=(8,)),
    uan=PhoneNumberDesc(national_number_pattern='77[1-9]\\d{5}', example_number='77273012', possible_length=(8,)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{3,4})', format='\\1 \\2 \\3', leading_digits_pattern=['[2-9]'], national_prefix_formatting_rule='0\\1')])
